context("Generic tests")
test_that("basic use case", {
  mod <- 1 : (2 * 3 * 4 * 5 * 6 * 8)
  dim(mod) <- c(dataset = 2, member = 3, sdate = 4, ftime = 5, lat = 6, lon = 8)
  obs <- 1 : (1 * 1 * 4 * 5 * 6 * 8)
  dim(obs) <- c(dataset = 1, member = 1, sdate = 4, ftime = 5, lat = 6, lon = 8)
  lon <- seq(0, 30, 5)
  lat <- seq(0, 30, 5)
  dat <- list(mod = mod, obs = obs, lat = lat, lon = lon)

  expect_equal(
    AnoMultiMetric(dat),
    list(ano = list(ano_exp = array(rep(
		    c(rep(-12, 6), rep(-4, 6), rep(4, 6), rep(12, 6)), 360),
                    dim = c(dataset = 2, member = 3, sdate = 4, ftime = 5, 
                            lat = 6, lon = 8)),
                    ano_obs = array(rep(c(-2, -2/3,  2/3,  2), 360),
                    dim = c(dataset = 1, member = 1, sdate = 4, ftime = 5,
                            lat = 6, lon = 8))),
         metric = array(rep(c(rep(1, 9), rep(0.9, 3)), 48), 
                        dim = c(dataset = 3, statistics = 1, sdates = 4, lat = 6, lon = 8)),
	 names = c("mod1", "mod2", "MMM")))
})


test_that("Sanity checks", {
  expect_error(
    AnoMultiMetric(),
    "argument "data" is missing, with no default")
  expect_error(
    AnoMultiMetric(data = 1),
      "Parameter 'data' must be a list as output of Load function
from s2dverification package")
  mod <- 1 : (2 * 3 * 4 * 5 * 6 * 8)
  dim(mod) <- c(dataset = 2, member = 3, sdate = 4, ftime = 5, lat = 6, lon = 8)
  obs <- 1 : (1 * 1 * 4 * 5 * 6 * 8)
  dim(obs) <- c(dataset = 1, member = 1, sdate = 4, ftime = 5, lat = 6, lon = 8)
  lon <- seq(0, 30, 5)
  lat <- seq(0, 30, 5)
  dat <- list(mod = mod, obs = obs, lat = lat, lon = lon)
  
  expect_error(
    AnoMultiMetric(data = dat, metric = 1),
    "Parameter 'metric' must be a character string indicating one of the 
         options: 'correlation', 'rms' or 'rmse'")
  expect_error(
    AnoMultiMetric(data = dat, metric = NA),
    "missing value where TRUE/FALSE needed")
  expect_error(
    AnoMultiMetric(data = dat, metric = NULL),
    "argument is of length zero")
  expect_error(
    AnoMultiMetric(data = dat, metric = "correlation", multimodel = NULL),
    "Parameter 'multimodel' must be a logical value.")
  expect_error(
    AnoMultiMetric(data = dat, metric = "correlation", multimodel = FALSE, names = 1),
    "Parameter 'names' must be the same length as the number of 
           models in the element 'mod' of parameter 'data'.")
})  